@@ -761,7 +761,7 @@ def main():
  if schoice == '1':
   os.system("clear")
   print(s1+':')
-  print('Link:','https://repl.it/@Craexz/'+s1+'/')
+  print('Link:','https://repl.it/@VO1D/'+s1+'/')
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -783,7 +783,7 @@ def main():
  if schoice == '3':
   os.system("clear")
   print(s3+':')
-  print('Link:','https://repl.it/@Craexz/'+s3)
+  print('Link:','https://repl.it/@VO1D/'+s3)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -828,7 +828,7 @@ def main():
  if schoice == '7':
   os.system("clear")
   print(s7+':')
-  print('Link:','https://repl.it/@Craexz/'+s7+'/')
+  print('Link:','https://repl.it/@VO1D/'+s7+'/')
   print("")
   input("Press enter to go back to the script list")
   os.system("clear")
@@ -837,7 +837,7 @@ def main():
  if schoice == '8':
   os.system("clear")
   print(s8+':')
-  print('Link:','https://repl.it/@craexz/'+s8+'/')
+  print('Link:','https://repl.it/@VO1D/'+s8+'/')
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
